import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:injectable/injectable.dart';

import '../local/shared_pref_source.dart';

@injectable
class ApiServiceHeaderInterceptor extends Interceptor {
  final SharePrefSource _localDataSource;
  ApiServiceHeaderInterceptor(this._localDataSource);

  @override
  Future<void> onRequest(
      RequestOptions options, RequestInterceptorHandler handler) async {
    if (!options.uri.origin.contains("fcm")) {
      options.headers.addAll(<String, String>{
        "Authorization": _localDataSource.getAuthToken() ?? "",
      });
    }
    debugPrint("\n"
        "Request ${options.uri} \n"
        "-- headers --\n"
        "${options.headers.toString()} \n"
        "-- param data --\n"
        "${options.data.toString()} \n"
        "");
    super.onRequest(options, handler);
  }

  @override
  Future<void> onResponse(
      Response response, ResponseInterceptorHandler handler) async {
    debugPrint("\n"
        "Response ${response.realUri} \n"
        "-- headers --\n"
        "${response.headers.toString()} \n"
        "-- payload --\n"
        "${response.requestOptions.toString()} \n"
        "-- Option --\n"
        "${jsonEncode(response.data)} \n"
        "");
    super.onResponse(response, handler);
  }

  @override
  void onError(DioError err, ErrorInterceptorHandler handler) {
    debugPrint("Dio Response Error --> $err");
    super.onError(err, handler);
  }
}
