import 'dart:async';
import 'dart:developer';
import 'dart:io';
import 'package:bloc/bloc.dart';

import 'presentation/app/app.dart';
import 'presentation/app/app_bloc_observer.dart';
import 'shared/theme/colors.dart';

import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'shared/di/injector.dart';
import 'core/data/service/constaints.dart';
import 'package:firebase_core/firebase_core.dart';
import 'package:sharing/sharing.dart';

void main() async {
  HttpOverrides.global = new MyHttpOverrides();
  debugPaintSizeEnabled = false;
  WidgetsFlutterBinding.ensureInitialized();
  await EasyLocalization.ensureInitialized();
  configureDependencies();
  await Firebase.initializeApp();

  Sharing.initLocal(
      domainUrl: ApiConstant.urlProduct,
      imageUrl: ApiConstant.urlUploadProduct,
      primaryColor: AppColors.colorBegin,
      primarySecondColor: AppColors.colorEnd,
      secondColor: AppColors.colorSecond,
      fontName: "Roboto",
      logo: "/images/ic_launcher.png",
      buttonColor: AppColors.colorEnd);

  FlutterError.onError = (details) {
    log(details.exceptionAsString(), stackTrace: details.stack);
  };
  SystemChrome.setPreferredOrientations(
    [DeviceOrientation.portraitUp, DeviceOrientation.portraitDown],
  );
  if (Platform.isAndroid) {
    SystemUiOverlayStyle systemUiOverlayStyle = SystemUiOverlayStyle(
        statusBarColor: Colors.transparent,
        statusBarIconBrightness: Brightness.dark,
        statusBarBrightness: Brightness.dark);
    SystemChrome.setSystemUIOverlayStyle(systemUiOverlayStyle);
  }
  FlutterError.onError = (details) {
    log(details.exceptionAsString(), stackTrace: details.stack);
  };
  runZonedGuarded(
    () async {
      BlocOverrides.runZoned(
        () async {
          runApp(
            EasyLocalization(
                supportedLocales: [Locale("vi"), Locale("en")],
                path: "assets/translations",
                fallbackLocale: Locale("vi"),
                child: MyApp(
                  isDevelop: false,
                )),
          );
        },
        blocObserver: AppBlocObserver(),
      );
    },
    (error, stackTrace) => log(error.toString(), stackTrace: stackTrace),
  );
}

class MyHttpOverrides extends HttpOverrides {
  @override
  HttpClient createHttpClient(SecurityContext? context) {
    return super.createHttpClient(context)
      ..badCertificateCallback =
          (X509Certificate cert, String host, int port) => true;
  }
}
