import 'package:fcm_config/fcm_config.dart';
import 'package:hainong_expert_module/presentation/app/app_bloc.dart';
import 'package:hainong_expert_module/presentation/app/app_event.dart';
import 'package:hainong_expert_module/presentation/app/app_state.dart';
import 'package:hainong_expert_module/shared/di/injector.dart';
import 'package:sharing/common/utils/helper/sizes_helper.dart';
import '../../core/routers/router.gr.dart';
import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import '../../shared/theme/styles.dart';

final GlobalKey<ScaffoldMessengerState> _scaffoldKey =
    new GlobalKey<ScaffoldMessengerState>();
final _navigatorKey = GlobalKey<NavigatorState>();
final _appRouter = AppRouter(_navigatorKey);
final appBloc = getIt<AppBloc>();

class MyApp extends StatefulWidget {
  final bool isDevelop;

  const MyApp({Key? key, this.isDevelop = false}) : super(key: key);
  @override
  State<MyApp> createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> with FCMNotificationClickMixin {
  final _appBloc = getIt<AppBloc>()..add(Init());

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    _appBloc.close();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: const SystemUiOverlayStyle(
        statusBarIconBrightness: Brightness.light,
        statusBarBrightness: Brightness.dark,
      ),
      child: MultiBlocProvider(
          providers: [
            BlocProvider<AppBloc>(create: (context) => _appBloc),
          ],
          child: BlocBuilder<AppBloc, AppState>(
            bloc: _appBloc,
            builder: (context, state) {
              return buildMaterialApp(context, state);
            },
          )),
    );
  }

  Widget buildMaterialApp(BuildContext context, AppState state) {
    return SizesHelper.ScreenConfig(
        builder: MaterialApp.router(
      title: "2nongModule",
      debugShowCheckedModeBanner: widget.isDevelop ? true : false,
      localizationsDelegates: context.localizationDelegates,
      locale: context.locale,
      supportedLocales: context.supportedLocales,
      scaffoldMessengerKey: _scaffoldKey,
      theme: Themes.getTheme(),
      routerDelegate: _appRouter.delegate(),
      routeInformationParser: _appRouter.defaultRouteParser(),
    ));
  }

  @override
  void onClick(RemoteMessage notification) async {}
}
