import '../../../core/data/local/shared_pref_source.dart';
import '../../../core/data/models/expert_model.dart';
import '../../../core/data/service/constaints.dart';
import 'package:injectable/injectable.dart';
import '../../../core/data/service/account_repository.dart';
import '../../../shared/base/base_bloc.dart';
import 'package:sharing/remote/network/fetch_data.dart';

import '../../../core/data/models/call_model.dart';
import '../../../shared/base/base_event.dart';
import '../../../shared/base/base_state.dart';

@injectable
class ExpertBloc extends BaseBloc {
  final AccountRepository accountRepository;

  final SharePrefSource sharePrefSource;

  ExpertBloc(this.accountRepository, this.sharePrefSource);

  @override
  void onMapEventToState() {
    on<CallEvent>(_onCall);
    on<GetExpertListEvent>(_onGetExpert);
    on<SendCallNotificationEvent>(_onSendCallNotification);
    on<SignOutEvent>(_onSignOut);
  }

  _onCall(event, emit) async {
    await accountRepository.call(
        receiverId: event.id.toString(),
        funDataServer: (data) {
          final result = data as FetchData<CallModel>;
          return emit(SuccessCallState(
              userId: event.id.toString(),
              data: result.data!,
              tokenFirebase: event.tokenId));
        },
        funError: (error) {
          return emit(safeErrorState(error: error));
        });
  }

  _onGetExpert(event, emit) async {
    await accountRepository.getExpertList(funDataServer: (data) {
      final result = data as FetchData<List<ExpertModel>>;
      return emit(SuccessDataState(data: result.data));
    }, funError: (error) {
      return emit(safeErrorState(error: error));
    });
  }

  _onSendCallNotification(SendCallNotificationEvent event, emit) async {
    final currentUser = sharePrefSource.getUser();
    if (currentUser != null) {
      await accountRepository.sendCallNotification(
          id: event.userId,
          authen: "key=${ApiConstant.serverToken}",
          name: event.name,
          phone: event.phone,
          roomId: event.roomId,
          usersId: [event.userId, currentUser.id.toString()],
          usersToNotify: [event.tokenId]);
    }
  }

  _onSignOut(event, emit) async {
    emit(LoadingState());
    await accountRepository.signOut();
    await sharePrefSource.resetAllCache();
    emit(SuccessLogOutState());
  }
}

class GetExpertListEvent extends BaseEvent {
  GetExpertListEvent();
}

class CallEvent extends BaseEvent {
  final int id;
  final String tokenId;
  CallEvent({required this.id, required this.tokenId});
}

class SendCallNotificationEvent extends BaseEvent {
  final String name;
  final String phone;
  final String roomId;
  final String tokenId;
  final String userId;
  SendCallNotificationEvent(
      {required this.roomId,
      required this.userId,
      required this.name,
      required this.phone,
      required this.tokenId});
}

class SignOutEvent extends BaseEvent {}

class SuccessCallState extends BaseState {
  final String userId;
  final CallModel data;
  final String tokenFirebase;
  SuccessCallState(
      {required this.userId, required this.data, required this.tokenFirebase});
}

class SuccessLogOutState extends BaseState {
  SuccessLogOutState();
}
