import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_animated_dialog/flutter_animated_dialog.dart';
import '../../../core/data/models/expert_model.dart';
import 'expert_bloc.dart';
import 'package:sharing/common/values/sizes.dart';
import 'package:sharing/widget/button/custom_button_label.dart';
import 'package:sharing/widget/custom/spaces.dart';
import 'package:sharing/widget/image/safe_image.dart';
import 'package:sharing/widget/text/custom_text_large_italic_field.dart';
import 'package:sharing/widget/text/custom_text_medium_bold_field.dart';
import 'package:sharing/widget/text/custom_text_medium_field.dart';
import '../../../shared/base/base_page.dart';
import '../../../shared/base/base_state.dart';

import 'package:chat_call_core/helper/connect_helper.dart';
import 'package:chat_call_core/presentation/call/call_page.dart';

class ExpertListPage extends BasePage {
  ExpertListPage();

  @override
  _ExpertListPageState createState() => _ExpertListPageState();
}

class _ExpertListPageState extends BasePageState<ExpertBloc> {
  List<ExpertModel>? data;

  @override
  void initBloc() {
    bloc?.add(GetExpertListEvent());
    isRefreshLoading = true;
  }

  @override
  void refreshPage() {
    bloc?.add(GetExpertListEvent());
  }

  @override
  bool listenerWhen(BaseState previous, BaseState state) {
    if (state is SuccessDataState<List<ExpertModel>>) {
      setState(() => data = state.data);
    } else if (state is SuccessCallState) {
      bloc?.add(SendCallNotificationEvent(
          userId: state.userId,
          roomId: state.data.roomName!,
          name: currentUser!.name!,
          phone: currentUser!.phone!,
          tokenId: state.tokenFirebase));
      ConnectHelper.connectRoomLiveKit(
        context,
        token: state.data.token!,
        (room, listener) {
          Navigator.push(
            context,
            MaterialPageRoute(builder: (context) => CallPage(room, listener)),
          );
          // context.pushRoute(RoomPageRoute(room: room, listener: listener));
        },
      );
    }
    return true;
  }

  @override
  Widget builder(BuildContext context, BaseState state) {
    return Scaffold(
        appBar: AppBar(
          backgroundColor: Theme.of(context).primaryColor,
          foregroundColor: Theme.of(context).primaryColor,
          leading: new IconButton(
            icon: new Icon(Icons.arrow_back, color: Colors.white),
            onPressed: () => Navigator.of(context).pop(),
          ),
          systemOverlayStyle: SystemUiOverlayStyle.light,
          title: CustomTextMediumField(
              color: Colors.white, label: "Gọi cho chuyên gia"),
        ),
        body: data != null
            ? Container(
                height: Sizes.height(context),
                child: ListView.separated(
                  shrinkWrap: true,
                  padding: EdgeInsets.zero,
                  physics: NeverScrollableScrollPhysics(),
                  scrollDirection: Axis.vertical,
                  itemBuilder: (context, index) =>
                      itemExpertBuilder(context, data![index], index),
                  itemCount: data?.length ?? 0,
                  separatorBuilder: (BuildContext context, int index) {
                    return SpaceH16();
                  },
                ),
              )
            : Container());
  }

  Widget itemExpertBuilder(BuildContext context, ExpertModel? data, int index) {
    return GestureDetector(
      onTap: () {
        // context.pushRoute(ChatPageRoute(room: room));
      },
      child: Container(
        padding: EdgeInsets.symmetric(
          horizontal: Sizes.PADDING_6,
          vertical: Sizes.PADDING_2,
        ),
        margin: EdgeInsets.symmetric(
            horizontal: Sizes.PADDING_4, vertical: Sizes.PADDING_4),
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(Sizes.RADIUS_4),
          border: Border.all(
            width: 1,
            color: Colors.blue.withOpacity(.3),
          ),
        ),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Expanded(
              child: Row(
                children: [
                  SafeImage(
                    imageUrl: data?.image,
                    width: Sizes.WIDTH_32,
                    height: Sizes.HEIGHT_40,
                    radius: Sizes.WIDTH_60,
                  ),
                  SpaceW12(),
                  Expanded(
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        CustomTextDefaultField(
                            textSize: Sizes.TEXT_SIZE_18,
                            color: Colors.blue,
                            label: data?.name),
                        CustomTextDefaultField(
                          color: Colors.green,
                          textSize: Sizes.TEXT_SIZE_18,
                          label: data?.phone,
                        ),
                        CustomTextDefaultField(
                          color: Colors.red,
                          textSize: Sizes.TEXT_SIZE_15,
                          label: data?.roleType?.toUpperCase(),
                        )
                      ],
                    ),
                  ),
                ],
              ),
            ),
            Row(
              children: [
                InkWell(
                  onTap: () async {},
                  child: Container(
                    padding: EdgeInsets.symmetric(
                        horizontal: Sizes.PADDING_8, vertical: Sizes.PADDING_2),
                    decoration: BoxDecoration(
                        border: Border.all(
                          width: 1,
                          color: Colors.blue.withOpacity(.3),
                        ),
                        borderRadius: BorderRadius.circular(Sizes.RADIUS_10)),
                    child: Row(
                      children: [
                        Icon(Icons.message, color: Colors.blue),
                        SpaceW4(),
                        CustomTextDefaultField(
                            label: "Chat", color: Colors.blue),
                      ],
                    ),
                  ),
                ),
                SpaceW8(),
                InkWell(
                  onTap: () async {
                    bloc?.add(CallEvent(
                        id: data!.id!, tokenId: data.currentDeviceToken));
                  },
                  child: Container(
                    padding: EdgeInsets.symmetric(
                        horizontal: Sizes.PADDING_8, vertical: Sizes.PADDING_2),
                    decoration: BoxDecoration(
                        border: Border.all(
                          width: 1,
                          color: Colors.blue.withOpacity(.3),
                        ),
                        borderRadius: BorderRadius.circular(Sizes.RADIUS_10)),
                    child: Row(
                      children: [
                        Icon(Icons.call, color: Colors.blue),
                        SpaceW4(),
                        CustomTextDefaultField(
                            label: "Call", color: Colors.blue),
                      ],
                    ),
                  ),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }

  void logout() async {
    customShowDialogExit();
  }

  Future<void> customShowDialogExit() async {
    await showAnimatedDialog(
      context: context,
      barrierDismissible: true,
      builder: (BuildContext context) {
        return Dialog(
          alignment: Alignment.center,
          shape: const RoundedRectangleBorder(
              borderRadius: BorderRadius.all(Radius.circular(12))),
          child: Container(
            height: Sizes.HEIGHT_160,
            padding: EdgeInsets.only(
                left: Sizes.PADDING_16,
                right: Sizes.PADDING_16,
                top: Sizes.PADDING_16),
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                CustomTextMediumBoldField(
                    align: TextAlign.center,
                    label: "Bạn có chắc muốn đăng xuất \n khỏi ứng dụng ?",
                    maxLine: 2),
                SpaceH20(),
                Container(
                  color: Colors.white,
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Expanded(
                          child: CustomButtonLable(
                              label: "No".tr(),
                              color: Colors.grey,
                              onPress: () {
                                Navigator.of(context).pop();
                              })),
                      SpaceW12(),
                      Expanded(
                          child: CustomButtonLable(
                              label: "Đồng ý".tr(),
                              onPress: () async {
                                bloc?.add(SignOutEvent());
                              })),
                    ],
                  ),
                )
              ],
            ),
          ),
        );
      },
      animationType: DialogTransitionType.fadeScale,
      curve: Curves.fastOutSlowIn,
      duration: const Duration(milliseconds: 100),
    );
  }
}
