import 'package:auto_route/auto_route.dart';
import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_animated_dialog/flutter_animated_dialog.dart';
import 'package:sharing/common/values/colors.dart';
import 'package:sharing/common/values/sizes.dart';
import 'package:sharing/widget/custom/custom_icon.dart';
import 'package:sharing/widget/dialog/custom_dialog_success.dart';
import 'package:sharing/widget/dialog/custom_dialog_warning_one_button.dart';
import 'package:sharing/widget/dialog/custom_dialog_warning_two_button.dart';
import 'package:sharing/widget/pages/page_loading_custom_widget_.dart';

mixin BaseDialogMixin<T extends StatefulWidget> on State<T> {
  void showDialogLoading({Duration? duration, String? msg}) {
    showDialog(
        barrierColor: Colors.white.withOpacity(0.5),
        context: context,
        barrierDismissible: true,
        builder: (BuildContext context) {
          return LoadingCustomPageWidget(duration: duration, msg: msg);
        });
  }

  void customShowDialogWaring({required List<String>? msg}) async {
    await showAnimatedDialog(
      context: context,
      barrierDismissible: true,
      builder: (BuildContext context) {
        return CustomDialogOne(
            content: msg,
            title: "text_warning".tr(),
            colorWarning: SharingColors.WarningColor,
            negativeBtnText: "text_ok".tr(),
            iconWarning: CustomIcon(
                icon: Icons.warning,
                color: Colors.white,
                size: Sizes.ICON_SIZE_24),
            positiveBtnPressed: () {
              Navigator.of(context, rootNavigator: true).pop();
            });
      },
      animationType: DialogTransitionType.fadeScale,
      curve: Curves.fastOutSlowIn,
      duration: Duration(milliseconds: 100),
    );
  }

  void customShowDialogTwoWaring(
      {required msg, bool? isRoot, Function()? callBack}) async {
    await showAnimatedDialog(
      context: context,
      barrierDismissible: true,
      builder: (BuildContext context) {
        return CustomDialogTwo(
          content: msg,
          title: "text_warning".tr(),
          colorWarning: SharingColors.WarningColor,
          negativeBtnText: "text_no".tr(),
          positiveBtnText: 'text_ok'.tr(),
          iconWarning: const CustomIcon(
            icon: Icons.warning,
            color: Colors.white,
            size: 24,
          ),
          positiveBtnPressed: () {
            if (isRoot == true) {
              context.router.popUntilRoot();
            } else {
              if (callBack != null) {
                callBack();
              } else {
                Navigator.of(context).pop();
              }
            }
          },
          negativeBtnPressed: () {},
        );
      },
      animationType: DialogTransitionType.fadeScale,
      curve: Curves.fastOutSlowIn,
      duration: const Duration(milliseconds: 100),
    );
  }

  void customShowDialogSuccess(
      {required String? msg, Function()? callback}) async {
    await showAnimatedDialog(
      context: context,
      barrierDismissible: true,
      builder: (BuildContext context) {
        return CustomDialogSuccess(
          content: msg,
          title: "text_success".tr(),
          positiveBtnText: 'text_ok'.tr(),
          positiveBtnPressed: () {
            if (callback != null) {
              callback();
            } else {
              Navigator.of(context).pop();
            }
          },
        );
      },
      animationType: DialogTransitionType.fadeScale,
      curve: Curves.fastOutSlowIn,
      duration: const Duration(milliseconds: 100),
    );
  }
}
