import 'dart:async';

import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:internet_connection_checker/internet_connection_checker.dart';
import 'package:sharing/common/values/sizes.dart';
import 'package:sharing/widget/custom/spaces.dart';
import 'package:sharing/widget/text/custom_text_default_field.dart';

mixin ConnectInternetMixin<T extends StatefulWidget> on State<T> {
  StreamSubscription<ConnectivityResult>? connectivitySubscription;
  Stream get connectionChange => connectionChangeController.stream;
  StreamController connectionChangeController =
      new StreamController.broadcast();
  bool isCheckConnect = true;
  bool isHasConnection = false;
  bool isShowConnectToast = false;

  void callRefreshPage();

  @override
  void initState() {
    if (isCheckConnect == true) initConnectivity();
    super.initState();
  }

  @override
  void dispose() {
    connectivitySubscription?.cancel();
    super.dispose();
  }

  // **************** BLOC REGISTER ***************
  Future<void> initConnectivity() async {
    connectivitySubscription?.cancel();
    isHasConnection = await InternetConnectionChecker().hasConnection;
    if (!isHasConnection) {
      setState(() => isShowConnectToast = true);
      print("CONNECTIVITY ===> FALSE");
    } else {
      if (isShowConnectToast) {
        setState(() => isHasConnection);
        setDismissHasConnect();
      }
      print("CONNECTIVITY ===> TRUE");
    }
    connectivitySubscription = Connectivity().onConnectivityChanged.listen(
      (result) {
        if (result == ConnectivityResult.none) {
          setState(() {
            isHasConnection = false;
            isShowConnectToast = true;
          });
          print("CONNECTIVITY ===> FALSE");
        } else {
          print("CONNECTIVITY ===> TRUE");
          if (!isHasConnection) {
            setState(() => isHasConnection = true);
            setDismissHasConnect();
          }
        }
      },
    );
  }

  void setDismissHasConnect() {
    Future.delayed(const Duration(milliseconds: 5000), () {
      setState(() => isShowConnectToast = false);
      callRefreshPage();
    });
  }

  Widget showConnectInternet() {
    return Visibility(
      visible: isShowConnectToast,
      child: Container(
        width: Sizes.width(context),
        height: Sizes.HEIGHT_32,
        color: isHasConnection == true
            ? Colors.green[400]?.withOpacity(0.4)
            : Colors.black87.withOpacity(0.4),
        padding: EdgeInsets.symmetric(horizontal: Sizes.PADDING_8),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Flexible(
              child: Icon(isHasConnection == true
                  ? CupertinoIcons.wifi
                  : CupertinoIcons.wifi_exclamationmark),
            ),
            SpaceW8(),
            Flexible(
              child: CustomTextDefaultField(
                label: isHasConnection == true
                    ? "text_data_online".tr()
                    : "text_data_offline".tr(),
                color: Colors.white,
              ),
            )
          ],
        ),
      ),
    );
  }
}
